' --------------------------------------------------------------------
' RedirectPrinter (device, path, updateProfile)
'	Maps a DOS printer device to a shared printer.
'
' Arguments:
'	device 	      - string value, DOS printer device name, e.g. "LPT1".
'			The device name cannot already be in use by a 
'			physical LPT port.
'	path 	      -	string value, UNC share name for the shared printer
'	updateProfile - True/False. If True, the mapping is made every logon.
'
' Return value:
'	True if the mapping was successfully made, False otherwise.
'	The value err.description should give the reason as a text string
'	(if you care).
'
' Example:
'	RedirectPrinter "LPT3", "\\server\HPLaserJet", True
' --------------------------------------------------------------------

function RedirectPrinter (byval device, byval path, byval updateProfile)
    dim maps, i, ismapped                     ' local variables
    dim devcolon, devnocolon

    device = ucase(device)                    ' put port name in uppercase
    i = instr(device, ":")                    ' get versions of name with
    if i > 0 then                             ' and without the colon
        devcolon   = device
        devnocolon = left(device, i-1)
    else
        devcolon   = device & ":"
        devnocolon = device
    end if

    RedirectPrinter = True                    ' assume success

    ismapped = False                          ' see if port already mapped
    set maps = wshNetwork.EnumPrinterConnections
    for i = 0 to maps.Length-2 step 2
        if maps.item(i) = devnocolon and _
                left(maps.item(i+1),2) = "\\" then ' port is already redirected
            ismapped = True
            exit for
        elseif maps.item(i) = devnocolon then ' port hooks to a local printer
            RedirectPrinter = False           ' we cannot redirect it
            exit function
        end if
    next

    if ismapped then
        err.Clear
        on error resume next                  ' delete existing  connection
        wshNetwork.RemovePrinterConnection device, True, updateProfile
        if err.number <> 0 then
            RedirectPrinter = False           ' return False if error
            exit function
        end if
        on error goto 0
    end if

    err.Clear
    on error resume next                      ' try to make the connection
    wshNetwork.AddPrinterConnection device, path, updateProfile
    if err.number <> 0 then RedirectPrinter = False   ' return False if error
    on error goto 0
end function

