' --------------------------------------------------------------------
' MapDrive (drive, path)
'	Map a drive letter to a network shared folder.
'	The mapping is not permanent (will not be reestablished next login)
'
' Arguments;
'	drive -	string value, drive letter to map.
'		(Only the first letter of 'drive' is examined)
'	path  - network share name in UNC format
'
' Return value:
'	True if the mapping was successfully made, False otherwise.
'	If the drive letter is already mapped to a network share, it is 
'	remapped to the specified network share.
'	Reasons for failure could be that the drive letter belongs to 
'	a local disk, the network share does not exist, or you do not have 
'	permission to use it. The value err.description should give the 
'	reason as a text string, if you care.
'
' Example:
'	MapDrive "R", "\\otherhost\Public"
'
'	if MapDrive("Z:", "\\server\sharename") then ...
' --------------------------------------------------------------------

function MapDrive(byval drive, byval path)
    MapDrive = True                            ' assume success

    if len(drive) = 1 then drive = drive & ":" ' ensure there's a colon

    if IsDriveMapped(drive) then             ' already mapped?
        if GetDriveMapping(drive) = ucase(path) then
            exit function                      ' ...as desired; quit now
        end if
        UnMap drive                            ' ...unmap before proceeding
    end if

    err.Clear
    on error resume next                       ' try to map, but don't halt
    wshNetwork.MapNetworkDrive drive, path     ' if there is an error
    on error goto 0

    if err.Number <> 0 then                    ' there was an error
         MapDrive = False                      ' report failure
    end if
end function
