					' Example file script0501.vbs

set wshNetwork = CreateObject("WScript.Network")
set wshShell   = CreateObject("WScript.Shell") 
set fso        = CreateObject("Scripting.FileSystemObject")

user = ucase(wshNetwork.userName)

mapdrive "H", "\\bali\home\" & user   ' map home drive

select case user
    case "BKNITTEL"		        ' map drive F and G
        mapdrive   "F", "\\sumatra\photos"
        mapdrive   "G", "\\ambon\software"
        wshShell.run "notepad c:\todo.txt" ' display to-do list
        useprinter "\\bali\okidata"

    case "NALEKS"                     ' just map the simulator folder
        mapdrive   "F", "\\bali\ibm360"

    case "ACCOUNTING"
        mapdrive   "X", "\\sumatra\quicken"

    case else ' for any other user, just set up network printer
        useprinter "\\bali\hp laserjet"
end select

' --------------------------------------------------------------------
' MapDrive (drive, path)
'	Map a drive letter to a network shared folder.
'	The mapping is not permanent (will not be reestablished next login)
'
' Arguments;
'	drive -	string value, drive letter to map.
'		(Only the first letter of 'drive' is examined)
'	path  - network share name in UNC format
'
' Return value:
'	True if the mapping was successfully made, False otherwise.
'	If the drive letter is already mapped to a network share, it is 
'	remapped to the specified network share.
'	Reasons for failure could be that the drive letter belongs to 
'	a local disk, the network share does not exist, or you do not have 
'	permission to use it. The value err.description should give the 
'	reason as a text string, if you care.
'
' Example:
'	MapDrive "R", "\\otherhost\Public"
'
'	if MapDrive("Z:", "\\server\sharename") then ...
' --------------------------------------------------------------------

function MapDrive(byval drive, byval path)

    wscript.echo "Map", drive, "to", path        ' display comment. You can remove this line if you want.

    MapDrive = True                            ' assume success

    if len(drive) = 1 then drive = drive & ":" ' ensure there's a colon

    if IsDriveMapped(drive) then             ' already mapped?
        if GetDriveMapping(drive) = ucase(path) then
            exit function                      ' ...as desired; quit now
        end if
        UnMap drive                            ' ...unmap before proceeding
    end if

    err.Clear
    on error resume next                       ' try to map, but don't halt
    wshNetwork.MapNetworkDrive drive, path     ' if there is an error
    if err.Number <> 0 then                    ' there was an error
         MapDrive = False                      ' report failure
    end if
    on error goto 0
end function

' --------------------------------------------------------------------
' UnMap(drive)
'	Cancel the mapping of a drive letter to a network shared folder.
'	The unmapping is permanent (mapping will not be done on next login)
'
' Arguments:
'	drive -	string value, drive letter to unmap.
'		(Only the first letter of 'drive' is examined)
'
' Return value:
'	True if the mapping was successfully canceled, False otherwise.
'	Reasons for failure could be that you had files in use on the
'	shared drive or the drive was not mapped to a network share.
'	The value err.description should give the reason as a text string
'	(if you care).
'
' Example:
'	UnMap "Z"
'	UnMap "Z:"
' --------------------------------------------------------------------

function UnMap(byval drive)
    UnMap = True                               ' assume success

    if len(drive) = 1 then drive = drive & ":" ' ensure there's a colon

    on error resume next                       ' try to unmap, but don't halt
    err.Clear                                  ' clear info for any previous errors
    wshNetwork.RemoveNetworkDrive drive, False, True ' if an error occurs
    if err.Number <> 0 then                    ' there was an error
         UnMap = False                         ' report failure
    end if
    on error goto 0
end function

' --------------------------------------------------------------------
' IsDriveMapped (drive)
'	Indicates whether or not a drive letter is a mapped 
'	network drive
'
' Arguments:
'	drive -	string value, drive letter to test.
'		(Only the first letter of 'drive' is examined)
'
' Return value:
'	True if the drive is a mapped network drive,
'	False if the drive is a local drive or is not a valid drive.
'
' Examples:
'	IsDriveMapped("Z") might return True
'	IsDriveMapped("Z:\files") would returns the same value
'	IsDriveMapped("C") would probably return False
' --------------------------------------------------------------------

function IsDriveMapped (byval drive)
' use only the letter, not :, and make sure it's uppercase
    drive = ucase(left(drive,1))

    ' assume it's not mapped
    IsDriveMapped = False

    ' if no such drive, return False right now
    if not fso.DriveExists(drive) then exit function

    ' get Drive object and check its type: 3 = mapped
    isDriveMapped = (fso.GetDrive(drive).driveType = 3)
end function

' --------------------------------------------------------------------
' GetDriveMapping (drive)
'	Find the network share name of a mapped network drive.
'
' Arguments:
'	drive -	string value, drive letter to test.
'		(Only the first letter of 'drive' is examined)
'
' Return value:
'	String value, the UNC path to the network share
'	corresponding to the drive letter, or the empty string
'	if the drive is not a mapped network drive.
'
' Example:
'	GetDriveMapping("P") might return "\\bigserver\public"
' --------------------------------------------------------------------

function GetDriveMapping (byval drive)
    dim i, maps

    ' use only the letter, not :, and make sure it's upper
    drive = ucase(left(drive,1))

    ' get list of mappings
    set maps = wshNetwork.EnumNetworkDrives

    ' assume it's not mapped
    GetDriveMapping = ""

    ' scan the list of mapped drives
    for i = 0 to maps.Length-2 step 2
        if ucase(left(maps.item(i),1)) = drive then
            ' the letter was listed, we have our answer
            GetDriveMapping = ucase(maps.item(i+1))
            exit for
        end if
    next
end function

' --------------------------------------------------------------------
' UsePrinter (path)
'	Install an icon for a network printer, given its UNC share name
'
' Arguments:
'	path -	UNC share name for the network printer
'
' Return value:
'	True if the mapping was successfully made, False otherwise.
'	The value err.description should give the reason as a text string
'	(if you care).
'
' Example:
'	UsePrinter "\\server\HPLaserjet"
' --------------------------------------------------------------------

function UsePrinter (path)
    UsePrinter = True              ' assume success

    wscript.echo "use printer", path    ' show what we're doing. You can remove this line if you want.

    err.Clear
    on error resume next           ' make connection, don't stop on error
    wshNetwork.AddWindowsPrinterConnection path
                                   ' if error occurred, return False
    if err.number <> 0 then UsePrinter = False
    on error goto 0
end function
