                                                ' Example file sendfax.vbs
    option explicit

                 ' constants needed by subroutines

    const STATUS_NOTFOUND      = 0 ' values returned by GetFaxStatus 
    const STATUS_PENDING       = 1
    const STATUS_SENDING       = 2
    const STATUS_DELIVERED     = 3
    const STATUS_FAILED        = 4

    const fjsPENDING           = &x00000001  ' status values
    const fjsINPROGRESS        = &x00000002
    const fjsFAILED            = &x00000008
    const fjsPAUSED            = &x00000010
    const fjsNOLINE            = &x00000020
    const fjsRETRYING          = &x00000040
    const fjsRETRIES_EXCEEDED  = &x00000080
    const fjsCOMPLETED         = &x00000100
    const fjsCANCELED          = &x00000200
    const fjsCANCELING         = &x00000400
    const fjsROUTING           = &x00000800

    const fjesNONE             = 0           ' extended status values
    const fjesDISCONNECTED     = 1
    const fjesINITIALIZING     = 2
    const fjesDIALING          = 3
    const fjesTRANSMITTING     = 4
    const fjesLINE_UNAVAILABLE = 7
    const fjesBUSY             = 8
    const fjesNO_ANSWER        = 9
    const fjesBAD_ADDRESS      = 10
    const fjesNO_DIAL_TONE     = 11
    const fjesFATAL_ERROR      = 12
    const fjesCALL_DELAYED     = 13
    const fjesCALL_BLACKLISTED = 14
    const fjesHANDLED          = 17
    const fjesCALL_COMPLETED   = 18
    const fjesCALL_ABORTED     = 19

    const fcptSERVER           = 2

    dim vistaOrBetter, faxid, whyfailed, finished, status, remark, server

    vistaOrBetter = (WindowsVersion() >= 6)     ' determine operating system

    ' send fax

    if SendByFax("c:\scripts\06\faxdoc.txt", _
                    "1-510-555-1212", _
                    "Recipient Person", _
                    "Remarks go here", _
                    faxid, whyfailed) then
	wscript.echo "Fax queued, ID:", faxid
    else
	wscript.echo "Fax failed:", whyfailed
        wscript.quit
    end if

    ' track fax to completion

    finished = false
    do
        wscript.sleep 5000		    ' pause 5 seconds
 
        GetFaxStatus faxid, status, remark ' get current status

        select case status		    ' display status:
	   case STATUS_PENDING:		    ' ... waiting in queue
		wscript.echo "Pending -", remark

	   case STATUS_SENDING:		    ' ... display transmit progress
		wscript.echo "Sending now - ", remark

	   case STATUS_DELIVERED:	    ' ... display recipient fax CSID
		wscript.echo "Delivery to", remark, "complete"
		finished = True
	
	   case STATUS_FAILED:		    ' ... display reason for failure
		wscript.echo "Cannot deliver:", remark
		finished = True

	    case STATUS_NOTFOUND:
		wscript.echo "Cannot locate fax in queue " & _
		    "or archive; was it deleted?"
		finished = True
 	end select
    loop until finished

' -----------------------------------------------------------------------------
' -----------------------------------------------------------------------------

sub GetFaxStatus (faxid, byval status, byval remark)
    dim ogQueue, ogArchive, ogFax

    if not isempty(server) then
        set server = CreateObject("FAXCOMEx.FaxServer")  ' create server object
        server.connect ""             ' connect to local computer's fax service
    end if

    set ogQueue   = server.Folders.OutgoingQueue     ' get references to queue
    set ogArchive = server.Folders.OutgoingArchive   ' and sent fax archive

    Set ogFax = Nothing          ' try to find fax in the outgoing queue
    on error resume next
    Set ogFax = ogQueue.GetJob(faxid)
    On Error GoTo 0
    If Not ogFax Is Nothing Then
	' found in the queue, get status information
        
	select case ogFax.status And Not (fjsPAUSED Or fjsNOLINE)
            case fjsPENDING:             status = STATUS_PENDING
            case fjsINPROGRESS:          status = STATUS_SENDING
            case fjsFAILED:              status = STATUS_FAILED
            case fjsRETRYING:            status = STATUS_PENDING
            case fjsRETRIES_EXCEEDED:    status = STATUS_FAILED
            case fjsCOMPLETED:           status = STATUS_DELIVERED
            case fjsCANCELED:            status = STATUS_FAILED
            case fjsCANCELING:           status = STATUS_FAILED
            case fjsROUTING:             status = STATUS_PENDING
            case Else:                   status = STATUS_FAILED
        end select
    
        select case ogFax.ExtendedStatusCode
            case fjesNONE:               remark = ""
            case fjesDISCONNECTED:       remark = "disconnected"
            case fjesINITIALIZING:       remark = "initializing"
            case fjesDIALING:            remark = "dialling"
            case fjesTRANSMITTING:       remark = "sending"
            case fjesLINE_UNAVAILABLE:   remark = "MODEM BUSY"
            case fjesBUSY:               remark = "BUSY SIGNAL"
            case fjesNO_ANSWER:          remark = "NO ANSWER"
            case fjesBAD_ADDRESS:        remark = "BAD FAX #"
            case fjesNO_DIAL_TONE:       remark = "NO DIAL TONE"
            case fjesFATAL_ERROR:        remark = "FAX ERROR"
            case fjesCALL_DELAYED:       remark = "BUSY/delay"
            case fjesCALL_BLACKLISTED:   remark = "BAD FAX #"   ' e.g. 911
            case fjesHANDLED:            remark = "handled"
            case fjesCALL_COMPLETED:     remark = "OK"
            case fjesCALL_ABORTED:       remark = "CANCELED"
            case Else:                   remark = "Code" & str(extcode)
        end select
    else
        ' was not in the queue, try to find it in the archive of sent faxes
        set sentFax = Nothing
        on error resume next
        set sentFax = ogArchive.GetMessage(faxid)
        on error goto 0
        if not sentFax is Nothing then
	    ' fax found in the archive, so it was successfully sent
	    status = STATUS_DELIVERED
	    remark = "Delivered to " & sentFax.CSID & ", " & _
		      cstr(sentFax.TransmissionEnd)
        else
            ' it's not in the archive either, must have been deleted
	    status = STATUS_NOTFOUND
	    remark = "Fax id " & faxid & " not found in queue or archive"
        end if
    end if
end sub

' -----------------------------------------------------------------------------
' SendByFax - fax a file to a recipient.
'
' Arguments:
'   fname       - full path and name of document to send
'   faxnum      - fax number, including all dialing and area codes
'   recipname   - recipient's name
'   subject     - subject line for cover sheet
'   note        - notes for cover sheet
'   faxid       - on True return, contains fax queue ID in hex
'   whyfailed   - on False return, contains error message
'
' Return value:
'   True if the fax was queued, False otherwise.
' -----------------------------------------------------------------------------

Private Function SendByFax(fname, faxnum, recipname, subject, note, _
                           ByRef faxid, ByRef whyfailed)
    Dim faxdoc
    
    SendByFax = False				' assume failure
    
    set faxdoc = CreateObject("FAXCOMEx.FaxDocument")
    
    with faxdoc
        .Body = fname				' set full path to document
        
        .Recipients.Add faxnum, recipname	' add the recipient

        .DocumentName  = "Fax to " & recipname	' set queue display name

        .CoverPage     = "generic.cov"		' use shared "generic" cover
        .CoverPageType = 

        .Subject = subject			' set cover sheet properties
        .Note    = note
        with .Sender
            .Name          = "My Name"
            .Company       = "My Company"
            .StreetAddress = "123 My Street"
            .City          = "Oakland"
            .State         = "CA"
            .ZipCode       = "94605"
            .Country       = "USA"
            .Email         = "myname@company.com"
            .FaxNumber     = "1-510-555-1212"
            .OfficePhone   = "1-510-555-2323"
            .TSID          = .FaxNumber
        end with

        err.clear                               ' capture errors
	on error resume next

        faxid = faxdoc.Submit("")               ' queue the fax

	if err.number <> 0 then
	    whyfailed = err.description  	' return error explanation
	    exit function
	end if
	on error goto 0
    end with

    if not vistaOrBetter then
        faxid = ConvertDecToHex64(faxid)   	' if XP, convert fax ID to hex
    end if

                                                ' pad fax ID out to 16 digits    
    faxid = Right("0000000000000000" & UCase(faxid), 16)
    
    ' from time to time, Submit fails w/o an error but with a fax id of 0.
    ' I have no idea why it does this, but we have to check for it

    If faxid = "0000000000000000" Then
	whyfailed = "Windows failed to queue the fax, try again"
    else
	SendByFax = True                         ' indicate success
    end if
end function

' -----------------------------------------------------------------------------
' WindowsVersion - get Windows version number. The return value will be one
' of the following:
' Value   Operating System
' ------  -------------------------------
'  5.0    Windows 2000, 2000 Server
'  5.1    Windows XP
'  5.2    Windows Server 2003, 2003 R2
'  6.0    Windows Vista, Server 2008
'  6.1    Windows 7, Server 2008 R2
' -----------------------------------------------------------------------------

function WindowsVersion ()
    dim os
                                              ' get Windows version using WMI
    for each os in GetObject(_
           "winmgmts:\\.\root\cimv2:Win32_OperatingSystem").Instances_
       WindowsVersion = val(os.version)       ' convern N.N.NNNN to decimal N.N
       exit function
    next

    WindowsVersion = 0                       ' in case WMI query fails
end function

' -----------------------------------------------------------------------------
' ConvertDecToHex64 - convert big decimal string into hex value
'
' Unfortunately VBScript cannot handle 64-bit integers, so we can't
' simply turn the string into an integer value with val(). Instead we
' split the 64-bit value into 8 one-byte values, and do the 64-bit math
' using these smaller pieces.
' -----------------------------------------------------------------------------

function ConvertDecToHex64 (ByVal decstr)
    dim digit, byteval(7), i                ' store the value as 8 bytes
    
    for i = 0 To 7                          ' zero the 64-bit value
        byteval(i) = 0
    next
    
    do while Len(decstr) > 0                ' convert decimal to binary
        digit  = val(Left(decstr, 1))       ' pull off leftmost digit
        decstr = mid(decstr, 2)
        
        bigmultadd byteval, 10, digit       ' multiply by 10 and add digit
    loop
                                            ' convert each byte to hex, 
    ConvertDecToHex64 = ""                  ' starting with most significant
    for i = 7 to 0 Step -1
        ConvertDecToHex64 = ConvertDecToHex64 & Right("00"+Hex(byteval(i)), 2)
    next
end function

' -----------------------------------------------------------------------------
' bigmultadd - multiply 64-bit value by factor, and add small (0..255) value
' -----------------------------------------------------------------------------

sub bigmultadd (byref byteval, factor, value)
    dim i, carry
    
    for i = 0 To 7                          ' multiply each byte
        byteval(i) = byteval(i) * factor
    next
    
    byteval(0) = byteval(0) + value         ' add in small value
    
    for i = 0 to 7                          ' perform carries
        if byteval(i) > 255 then
            carry = int(byteval(i) / 256)
            byteval(i) = byteval(i) mod 256
            if i < 7 then byteval(i + 1) = byteval(i + 1) + carry
        end if
    next
end sub
