option explicit
dim fso, summaryfile, recipient, summary, sum, msg
set fso = CreateObject("Scripting.FileSystemObject")
const ForAppending = 8

summaryfile = "c:\scripts\logs\summary.log"
recipient   = "Administrator@mycompanyxyz.com"

summary     = ""   ' summary text is accumulated in this string

' summarize all of the nightly scheduled scripts
summarize "c:\scripts\logs\sched.log"
summarize "c:\scripts\logs\cleanup.log"
summarize "c:\scripts\logs\backup.log"

' create a new summary file
set sum = fso.CreateTextFile(summaryfile, True)
sum.Write summary
sum.Close

' then mail the summary using the object developed in Chapter 9
set msg = CreateObject("ScriptMail.Message")
msg.To = recipient
msg.ScriptName = "summarize"
msg.Text = summary
msg.Send

' ---------------------------------------------------
' summarize - record the last line and any errors from 'filename'

sub summarize (filename)
    dim stream, outstream, line, lastline

    ' first time through, note the date and time
    if summary = "" then
        summary = "Batch summary, " & date & " " & time & vbCRLF & vbCRLF
    end if

    ' note the file we're examining
    summary = summary & filename & ":" & vbCRLF

    ' if file doesnt exist, that's all we can say
    if not fso.FileExists(filename) then
        summary = summary & "    FILE NOT FOUND!" & vbCRLF & vbCRLF
        exit sub
    end if

    set stream = fso.OpenTextFile(filename)

    ' we dont want to summarize the same log info every night, so
    ' tack the log file contents onto the end of the same filename + ".old", and
    ' delete the original log when we're done.

    set outstream = fso.OpenTextFile(filename & ".old", ForAppending, True)

    ' run through the log file, picking up any errors and saving the last line
    lastline = "(empty file)"
    do while not stream.AtEndOfStream
        line = stream.ReadLine               ' get line from log file
        outstream.WriteLine line             ' append to .OLD copy

        if instr(ucase(line), "ERROR") > 0 then
            summary = summary & "    " & line & vbCRLF
        elseif len(line) > 0 then
            lastline = line
        end if
    loop
    stream.close
    outstream.close

    ' note the last line; it should be the "completed successfully" line
    summary = summary & "    " & lastline & vbCRLF & vbCRLF

    ' we've copied the log to .OLD, so delete the original log file now
'    fso.DeleteFile(filename)
end sub
