@rem                              Example File mkaccount.bat 
@echo off

rem --------------------------------------------
rem Create a student account
rem Be sure the command line contains a classname, username and password
rem --------------------------------------------

if "%3" == "" (
    echo Usage: mkaccount classname username password
    exit /b
)

rem --------------------------------------------
rem Attempt to create the account. Throughout this
rem batch file %1 is the class name (e.g. CS101),
rem %2 is the new logon name (e.g. asmith), and
rem %3 is the initial password (e.g. xyz123)
rem --------------------------------------------

net user "%2" "%3" /add /passwordreq:yes /domain

if errorlevel 1 (
    echo Unable to create account %2
    pause
    exit /b
)

rem --------------------------------------------
rem Add the new user to the class group and the
rem students group
rem --------------------------------------------

net group "%1" "%2" /add
net group students "%2" /add

rem --------------------------------------------
rem Create the user's profile folder and grant
rem Full access rights to the new student account. The
rem teacher already has full rights to
rem \classes\classname so she or he will inherit rights
rem to the student's directory.
rem For the roaming profile to work, the "students" group
rem must have read permissions on the class folder but
rem but this permission must not apply to subfolders.
rem --------------------------------------------

mkdir "d:\home\classes\%1\%2"
cacls "d:\home\classes\%1\%2" /E /G "%2:F"

rem --------------------------------------------
rem Assign the profile folder using the network path
rem \\server\classes to the folder d:\home\classes
rem --------------------------------------------

net user "%2" /profilepath:"\\server\classes\%1\%2" /domain
